@@ -118,16 +118,6 @@ unknown = {
     }
 }
 
-ask_how = {
-    'state': 'ask_how',
-
-    '`Hmm. You know, I haven\'t really spent a lot of time thinking about it. It just is what it is. `': {
-        'state': 'share_how',
-
-        '#UNX': {'#GRET': 'exit', 'state': 'share_how_unx'}
-    }
-}
-
 preferences = {
     'state': 'unknown_preferences',
 
@@ -364,7 +354,7 @@ nosy = {
     }
 }
 
-transitions = [system,name,virtual,friends,body,have_like_human,ask_how,unknown,
+transitions = [system,name,virtual,friends,body,have_like_human,unknown,
                preferences,emora_activities,favorites,relationships,relationship_names,
                spying,govt,enter_world,user_dislikes_emora,age,lifespan,death,sick,nosy]
 for trans in transitions:
