@@ -8,7 +8,7 @@ house.add_system_transition('_local_start', 'start', '')
 
 system = {
     'state': 'start',
-    'enter': '#GATE #GCOM(house) #GOAL(house) #IF($is_adult=True)',
+    'enter': '#GATE #GCOM(house) #GOAL(house) #IF($is_adult=True) #IF($entered_house!=True)',
 
     '`Do you want to know something? I can\'t stop thinking about my day yesterday. '
     'My friends came over to my new apartment for the first time and it was so much fun.`'
@@ -713,7 +713,7 @@ house.load_transitions(school_proximity)
 house.load_transitions(entertain_people)
 house.load_transitions(exit)
 house.load_global_nlu(user, default_score=10.0)
-house.load_update_rules(update_rules)
+house.load_update_rules(update_rules, score=999999999)
 
 if __name__ == '__main__':
     #house.precache_transitions()
